Enum curve25519_dalek::backend::vector::avx2::field::Lanes [−][src]
pub enum Lanes {
C,
D,
AB,
AC,
CD,
AD,
BC,
ABCD,
}This is supported on crate feature
simd_backend and (target features avx2 or avx512ifma) and target feature avx2 and non-target feature avx512ifma only.Expand description
The Lanes enum represents a subset of the lanes A,B,C,D of a
FieldElement2625x4.
It’s used to specify blend operations without
having to know details about the data layout of the
FieldElement2625x4.
Variants